@@ -281,6 +281,8 @@
 ;;   - Added "Owner:" to ITP bugs. Thanks to Romain Francoise for bringing
 ;;     this to my attention (Closes: #388747)
 ;;   - Updated the list of valid tags.
+;; V1.63 25Jul2007 Peter S Galbraith <psg@debian.org>
+;;  - Adapt patch from Luca Capello <luca@pca.it> for bug #431091
 ;; ----------------------------------------------------------------------------
 
 ;;; Todo (Peter's list):
@@ -349,6 +351,20 @@ Use it to specify what email your bugs will be archived under."
 ;;   :group 'debian-bug
 ;;   :type 'boolean)
 
+;; This function is from emacs/lisp/calendar/icalendar.el,
+;; necessary to replace "%s" with the bug number in
+;; `debian-changelog-close-bug-statement'
+(defsubst debian-bug--rris (&rest args)
+  "Replace regular expression in string.
+Pass ARGS to `replace-regexp-in-string' (GNU Emacs) or to
+`replace-in-string' (XEmacs)."
+  ;; XEmacs:
+  (if (fboundp 'replace-in-string)
+      (save-match-data ;; apparently XEmacs needs save-match-data
+        (apply 'replace-in-string args))
+    ;; Emacs:
+    (apply 'replace-regexp-in-string args)))
+
 (defvar debian-bug-minor-mode nil)
 (defvar debian-bug-minor-mode-map nil
   "Keymap for `debian-bug' minor mode.")
@@ -466,11 +482,11 @@ Debian maintainers.")
   "Alist of all valid Tags, aimed at Debian developpers.")
 
 (defvar debian-bug-pseudo-packages
-  '("base" "boot-floppy" "bugs.debian.org" "cdimage.debian.org" "cdrom"
-    "ftp.debian.org" "general" "install" "installation"
+  '("base" "bugs.debian.org" "cdimage.debian.org" "cdrom"
+    "ftp.debian.org" "general"
     "installation-reports" "kernel" "listarchives"
-    "lists.debian.org" "mirrors" "nonus.debian.org" "potato-cd" "press"
-    "project" "qa.debian.org" "security.debian.org" "tech-ctte"
+    "lists.debian.org" "mirrors" "press"
+    "project" "qa.debian.org" "release-notes" "security.debian.org" "tech-ctte"
     "upgrade-reports" "wnpp" "www.debian.org")
   "List of Debian pseudo-packages available for completion.
 See http://www.debian.org/Bugs/pseudo-packages")
@@ -1814,7 +1830,7 @@ Only decodes if `rfc2047-decode-string' is available."
               (setq bug-alist (cons (list bugnumber description) bug-alist))
               (when bugs-are-open-flag
                 (when (and (re-search-forward
-                            "Reported by: <a class=\"submitter\" href=\"pkgreport.cgi\\?submitter=[^;]+;arch=source\">"
+                            "Reported by: <a class=\"submitter\" href=\"pkgreport.cgi\\?submitter=[^\"]+\">"
                             nil t)
                            (or (looking-at "&quot;\\(.*\\)&quot; &lt;")
                                (looking-at "\\(.*\\) &lt;")
@@ -1824,7 +1840,9 @@ Only decodes if `rfc2047-decode-string' is available."
                                 "\", thanks to "
                                 (debian-bug-rfc2047-decode-string
                                  (match-string 1))
-                                " (Closes: #" bugnumber ").")))
+                                " " (debian-bug--rris
+				     "%s" bugnumber
+				     debian-changelog-close-bug-statement))))
                 (setq bug-open-alist
                       (cons
                        (list bugnumber shortdescription) bug-open-alist)))
