@@ -25,7 +25,7 @@
 ;;; Commentary:
 ;;
 ;;  Use `M-x debian-bts-control' to create an initial message, and
-;;  `M-x debian-bts-control' again (or `C-c c') to insert new directives.
+;;  `M-x debian-bts-control' again (or `C-c C-b') to insert new directives.
 
 ;;; Change log:
 ;;
@@ -56,6 +56,8 @@
 ;;      (debian-bts-control-prompt): Code structure slightly redesigned.
 ;;      (debian-bts-control): Use `debian-bts-bug-number-at-point' to
 ;;      set `number-default'.
+;; V1.08 08Aug2007 Peter S Galbraith <psg@debian.org>
+;;  - Use `C-c C-b' instead of `C-c c' (Closes: #435247).
 
 ;;; Code:
 
@@ -82,7 +84,7 @@
   '(mh-letter-mode mail-mode message-mode)
   "List of modes in which calling `debian-bts-control' will reuse the buffer.
 No new draft will be created.  Instead control@bugs.debian.org will be
-added to the Cc: field and the comamnds added at t6he top of the message."
+added to the Cc: field and the comamnds added at the top of the message."
   :group 'debian-bts-control
   :type '(repeat symbol))
 
@@ -92,7 +94,7 @@ added to the Cc: field and the comamnds added at t6he top of the message."
 (if debian-bts-control-minor-mode-map
     nil
   (setq debian-bts-control-minor-mode-map (make-sparse-keymap))
-  (define-key debian-bts-control-minor-mode-map "\C-cc" 'debian-bts-control))
+  (define-key debian-bts-control-minor-mode-map "\C-c\C-b" 'debian-bts-control))
 
 (easy-menu-define debian-bts-control-menu debian-bts-control-minor-mode-map
   "Debian Bug Mode Menu"
