@@ -303,6 +303,24 @@
 ;;    suggested by Romain Francoise <rfrancoise@debian.org> (Closes: #322994)
 ;; V1.82 05Sep2006 Peter Samuelson <peter@p12n.org>
 ;;  - Add tilde support for upstream version numbers (Closes: #382514)
+;; V1.83 11Oct2006 Luca Capello <luca@pca.it>
+;;  - Rename `debian-changelog-maintainer' to `debian-changelog-last-maintainer',
+;;    this is what the function really work on
+;;  - `debian-changelog-last-maintainer' now returns a list of "(NAME EMAIL)"
+;;    and not only EMAIL
+;;  - Add `debian-changelog-comaintainer-insert', which actually inserts the
+;;    co-maintainer name in the form "[ NAME ]"
+;;  - Add `debian-changelog-comaintainer', which checks if we're in a
+;;    co-maintenance, calling `debian-changelog-comaintainer-insert'
+;;  - Add co-maintenance support to `debian-changelog-unfinalise-last-version'
+;; V1.84 14May2007 Peter S Galbraith <psg@debian.org>
+;;  - Use "date -R" instead of deprecated "822-date"
+;;    (Closes: #423142, #423155, #423828) 
+;;  - Tighter regexp for finalisation string
+;; V1.85 25Jul2007 Peter S Galbraith <psg@debian.org>
+;;  - Adapt patch from Luca Capello <luca@pca.it> for bug #431091
+;; V1.86 08Aug2007 Peter S Galbraith <psg@debian.org>
+;;  - auto-mode-alist  for "/debian/*NEWS" files (Closes: #424779)
 
 ;;; Acknowledgements:  (These people have contributed)
 ;;   Roland Rosenfeld <roland@debian.org>
@@ -363,6 +381,14 @@ If you do not wish this behaviour, reset it in your .emacs file like so:
   :group 'debian-changelog
   :type 'boolean)
 
+;; This solves the consistency problem with `debian-changelog-close-bug'
+;; as per bug #431091
+(defcustom debian-changelog-close-bug-statement "(Closes: #%s)."
+  "The text to be inserted to close a bug.  `%s' is replaced by
+the bug number."
+  :group 'debian-changelog
+  :type 'string)
+
 (defcustom debian-changelog-mode-hook nil
   "Normal hook run when entering Debian Changelog mode."
   :group 'debian-changelog
@@ -376,6 +402,20 @@ new version in debian/changelog."
   :group 'debian-changelog
   :type 'hook)
 
+;; This function is from emacs/lisp/calendar/icalendar.el,
+;; necessary to replace "%s" with the bug number in
+;; `debian-changelog-close-bug-statement'
+(defsubst debian-changelog--rris (&rest args)
+  "Replace regular expression in string.
+Pass ARGS to `replace-regexp-in-string' (GNU Emacs) or to
+`replace-in-string' (XEmacs)."
+  ;; XEmacs:
+  (if (fboundp 'replace-in-string)
+      (save-match-data ;; apparently XEmacs needs save-match-data
+        (apply 'replace-in-string args))
+    ;; Emacs:
+    (apply 'replace-regexp-in-string args)))
+
 (defvar debian-changelog-local-variables-maybe-remove-done nil
   "Internal flag so we prompt only once.")
 
@@ -782,7 +822,9 @@ for the debian/changelog file to add the entry to."
     (insert (cadr (assoc bug-number debian-bug-open-alist)))
     (fill-paragraph nil))
    (t
-    (save-excursion (insert " (closes: #" bug-number ")"))
+    (save-excursion
+      (insert " " (debian-changelog--rris
+		   "%s" bug-number debian-changelog-close-bug-statement)))
     (message "Enter a brief description of what was done here."))))
 
 ;;
@@ -1104,9 +1146,9 @@ If file is empty, create initial entry."
 
 (defun debian-changelog-date-string ()
   "Return RFC-822 format date string."
-  (let* ((dp "822-date")
+  (let* ((dp "date")
 	 (cp (point))
-	 (ret (call-process "822-date" nil t))
+	 (ret (call-process "date" nil t nil "-R"))
 	 (np (point))
 	 (out nil))
     (cond ((not (or (eq ret nil) (eq ret 0)))
@@ -1144,15 +1186,18 @@ If file is empty, create initial entry."
             " <" debian-changelog-mailing-address ">  "
 	    (debian-changelog-date-string))))
 
-(defun debian-changelog-maintainer ()
-  "Return maintainer of last changelog entry."
+(defun debian-changelog-last-maintainer ()
+  "Return maintainer name and e-mail of the last changelog entry as
+a list in the form (NAME EMAIL)."
   (save-excursion
     (goto-char (point-min))
-    (if (re-search-forward "^ -- .*<\\(.*\\)>" nil t)
-        (if (fboundp 'match-string-no-properties)
-            (match-string-no-properties 1)
-          (match-string 1))
-      (error "Maintainer name not found."))))
+    (let ((string
+	   (if (re-search-forward "^ -- \\(.*\\)>" nil t)
+	       (if (fboundp 'match-string-no-properties)
+		   (match-string-no-properties 1)
+		 (match-string 1))
+	     (error "Maintainer name and email not found."))))
+      (split-string string " <"))))
 
 (defun debian-changelog-web-developer-page ()
   "Browse the BTS for the last upload maintainer's developer summary page."
@@ -1162,9 +1207,47 @@ If file is empty, create initial entry."
         (load "browse-url" nil t)
         (if (not (featurep 'browse-url))
             (error "This function requires the browse-url elisp package"))))
-  (let ((name (debian-changelog-maintainer)))
-    (browse-url (concat "http://qa.debian.org/developer.php?login=" name))
-    (message "Looking up developer summary page for %s via browse-url" name)))
+  (let ((email (cadr (debian-changelog-last-maintainer))))
+    (browse-url (concat "http://qa.debian.org/developer.php?login=" email))
+    (message "Looking up developer summary page for %s via browse-url" email)))
+
+;; co-maintenance as per bug #352957 by Luca Capello 2006
+(defun debian-changelog-comaintainer-insert (name separator)
+  "In the line before SEPARATOR, insert the co-maintainer name as for
+the form [ NAME ]."
+  (goto-char (point-min))
+  (re-search-forward (concat "\n " separator))
+  (previous-line 1)
+  (insert "\n  [ " name " ]")
+  (when (string= "--" separator)
+    (insert "\n")))
+  
+(defun debian-changelog-comaintainer ()
+  "If the last maintainer is different from the current one, create a
+co-maintained changelog entry."
+  (let ((name (car (debian-changelog-last-maintainer))))
+    (unless (string= name debian-changelog-full-name)
+      (let ((maintainers-found)
+	    (debian-changelog-last-entry-end
+	     (progn (goto-char (point-min))
+		    (re-search-forward "\n --"))))
+	(mapc (lambda (x)
+		(goto-char (point-min))
+		(when (search-forward x debian-changelog-last-entry-end t)
+		  (add-to-list 'maintainers-found x)))
+	      (list name debian-changelog-full-name))
+	;; set the co-maintenance if any
+	(if maintainers-found
+	    ;; co-maintenance, debian-changelog-full-name is not present
+	    (if (and (member name maintainers-found)
+		     (not (member debian-changelog-full-name
+				  maintainers-found)))
+		(debian-changelog-comaintainer-insert
+		 debian-changelog-full-name "--"))
+	  ;; no co-maintenance
+	  (mapc (lambda (x)
+		  (debian-changelog-comaintainer-insert (car x) (cadr x)))
+		`((,name " *") (,debian-changelog-full-name "--"))))))))
 
 ;;
 ;; interactive function to unfinalise changelog (so modifications can be made)
@@ -1178,6 +1261,7 @@ can be made."
   (if (debian-changelog-finalised-p) nil
     (error "Most recent version is not finalised"))
   (save-excursion
+    (debian-changelog-comaintainer)
     (goto-char (point-min))
     (re-search-forward "\n --")
     (let ((dels (point)))
@@ -1355,7 +1439,7 @@ match 1 -> package name
 ;;; The following is not strictly correct.  The upstream version may actually
 ;;; contain a hyphen if a debian version number also exists, making two hyphens
 ;;; I'm assuming it begins with a digit, which is not enforced
-         "^\\(\\S-+\\) +(\\([0-9]:\\)?\\([0-9][0-9a-zA-Z.+:~]*\\)\\(-\\([0-9a-zA-Z.+~]+\\)\\)*)" nil t)
+         "^\\(\\S-+\\) (\\([0-9]:\\)?\\([0-9][0-9a-zA-Z.+:~]*\\)\\(-\\([0-9a-zA-Z.+~]+\\)\\)*)" nil t)
 ;;                                                                                           ^
 ;; Note the asterix above, allowing more than one hyphen in the version
 ;; number, but wrongly assuming that all of it is the Debian version
@@ -1640,6 +1724,7 @@ Also set keymap."
 ;;; Setup auto-mode-alist
 ;; (in case /etc/emacs/site-start.d/50dpkg-dev.el not used)
 
+(add-to-list 'auto-mode-alist '("/debian/*NEWS" . debian-changelog-mode))
 (add-to-list 'auto-mode-alist '("NEWS.Debian" . debian-changelog-mode))
 (add-to-list 'auto-mode-alist '("NEWS.Debian.gz" . debian-changelog-mode))
 (add-to-list 'auto-mode-alist
@@ -1649,6 +1734,7 @@ Also set keymap."
   ;; For debchange
 (add-to-list 'auto-mode-alist '("changelog.dch" . debian-changelog-mode))
 
+;;;###autoload(add-to-list 'auto-mode-alist '("/debian/*NEWS" . debian-changelog-mode))
 ;;;###autoload(add-to-list 'auto-mode-alist '("NEWS.Debian" . debian-changelog-mode))
 ;;;###autoload(add-to-list 'auto-mode-alist '("NEWS.Debian.gz" . debian-changelog-mode))
 ;;;###autoload(add-to-list 'auto-mode-alist '("/debian/changelog\\'" . debian-changelog-mode))
